@@ -1,6 +1,6 @@
 #!/bin/bash
 
 # fix logrotate config
-sed -i "s/weekly/daily/" /etc/logrotate.conf
+sed -i "s/\(weekly\|monthly\|yearly\)/daily/" /etc/logrotate.conf
 
 # default for cron.daily for RHEL7 is already correct
