@@ -14,7 +14,7 @@ from .constants import puppet_system as puppet_rem_system
 from .constants import anaconda_system as anaconda_rem_system
 from .constants import cce_uri
 from .constants import ssg_version_uri
-from .constants import stig_ns
+from .constants import stig_ns, cis_ns, hipaa_ns, anssi_ns
 console_width = 80
 
 
@@ -27,7 +27,7 @@ class RuleStats(object):
                  rbash_fix=None, ransible_fix=None,
                  rignition_fix=None, rkubernetes_fix=None,
                  rpuppet_fix=None, ranaconda_fix=None, rcce=None,
-                 stig_id=None):
+                 stig_id=None, cis_ref=None, hipaa_ref=None, anssi_ref=None):
         self.dict = {
             'id': rid,
             'oval': roval,
@@ -39,6 +39,9 @@ class RuleStats(object):
             'anaconda_fix': ranaconda_fix,
             'cce': rcce,
             'stig_id': stig_id,
+            'cis_ref': cis_ref,
+            'hipaa_ref': hipaa_ref,
+            'anssi_ref': anssi_ref,
         }
 
 
@@ -104,6 +107,9 @@ class XCCDFBenchmark(object):
             'assigned_cces_pct': 0,
             'missing_cces': [],
             'missing_stig_ids': [],
+            'missing_cis_refs': [],
+            'missing_hipaa_refs': [],
+            'missing_anssi_refs': [],
             'ansible_parity': [],
         }
 
@@ -161,12 +167,18 @@ class XCCDFBenchmark(object):
                                 (xccdf_ns, cce_uri))
                 stig_id = rule.find("./{%s}reference[@href=\"%s\"]" %
                                     (xccdf_ns, stig_ns))
+                cis_ref = rule.find("./{%s}reference[@href=\"%s\"]" %
+                                    (xccdf_ns, cis_ns))
+                hipaa_ref = rule.find("./{%s}reference[@href=\"%s\"]" %
+                                    (xccdf_ns, hipaa_ns))
+                anssi_ref = rule.find("./{%s}reference[@href=\"%s\"]" %
+                                    (xccdf_ns, anssi_ns))
 
                 rule_stats.append(
                     RuleStats(rule.get("id"), oval,
                               bash_fix, ansible_fix, ignition_fix,
                               kubernetes_fix, puppet_fix, anaconda_fix,
-                              cce, stig_id)
+                              cce, stig_id, cis_ref, hipaa_ref, anssi_ref)
                 )
 
         if not rule_stats:
@@ -239,6 +251,21 @@ class XCCDFBenchmark(object):
             profile_stats['missing_stig_ids'] = \
                 [x.dict['id'] for x in rule_stats if x.dict['stig_id'] is None]
 
+        profile_stats['missing_cis_refs'] = []
+        if 'cis' in profile_stats['profile_id']:
+            profile_stats['missing_cis_refs'] = \
+                [x.dict['id'] for x in rule_stats if x.dict['cis_ref'] is None]
+
+        profile_stats['missing_hipaa_refs'] = []
+        if 'hipaa' in profile_stats['profile_id']:
+            profile_stats['missing_hipaa_refs'] = \
+                [x.dict['id'] for x in rule_stats if x.dict['hipaa_ref'] is None]
+
+        profile_stats['missing_anssi_refs'] = []
+        if 'anssi' in profile_stats['profile_id']:
+            profile_stats['missing_anssi_refs'] = \
+                [x.dict['id'] for x in rule_stats if x.dict['anssi_ref'] is None]
+
         profile_stats['implemented_anaconda_fixes_pct'] = \
             float(len(profile_stats['implemented_anaconda_fixes'])) / \
             profile_stats['rules_count'] * 100
@@ -277,6 +304,9 @@ class XCCDFBenchmark(object):
         impl_puppet_fixes_count = len(profile_stats['implemented_puppet_fixes'])
         impl_anaconda_fixes_count = len(profile_stats['implemented_anaconda_fixes'])
         missing_stig_ids_count = len(profile_stats['missing_stig_ids'])
+        missing_cis_refs_count = len(profile_stats['missing_cis_refs'])
+        missing_hipaa_refs_count = len(profile_stats['missing_hipaa_refs'])
+        missing_anssi_refs_count = len(profile_stats['missing_anssi_refs'])
         impl_cces_count = len(profile_stats['assigned_cces'])
 
         if options.format == "plain":
@@ -453,6 +483,33 @@ class XCCDFBenchmark(object):
                 self.console_print(profile_stats['missing_stig_ids'],
                                    console_width)
 
+            if options.missing_cis_refs and profile_stats['missing_cis_refs']:
+                print("*** rules of '%s' profile missing "
+                      "CIS Refs: %d of %d have them [%d%% missing]"
+                      % (profile, rules_count - missing_cis_refs_count,
+                         rules_count,
+                         (100.0 * missing_cis_refs_count / rules_count)))
+                self.console_print(profile_stats['missing_cis_refs'],
+                                   console_width)
+
+            if options.missing_hipaa_refs and profile_stats['missing_hipaa_refs']:
+                print("*** rules of '%s' profile missing "
+                      "HIPAA Refs: %d of %d have them [%d%% missing]"
+                      % (profile, rules_count - missing_hipaa_refs_count,
+                         rules_count,
+                         (100.0 * missing_hipaa_refs_count / rules_count)))
+                self.console_print(profile_stats['missing_hipaa_refs'],
+                                   console_width)
+
+            if options.missing_anssi_refs and profile_stats['missing_anssi_refs']:
+                print("*** rules of '%s' profile missing "
+                      "ANSSI Refs: %d of %d have them [%d%% missing]"
+                      % (profile, rules_count - missing_anssi_refs_count,
+                         rules_count,
+                         (100.0 * missing_anssi_refs_count / rules_count)))
+                self.console_print(profile_stats['missing_anssi_refs'],
+                                   console_width)
+
             if options.missing_cces and profile_stats['missing_cces']:
                 print("***Rules of '%s' " % profile + "profile missing " +
                       "CCE identifier: %d of %d [%d%% complete]" %
@@ -481,6 +538,9 @@ class XCCDFBenchmark(object):
             del profile_stats['assigned_cces']
 
             profile_stats['missing_stig_ids_count'] = missing_stig_ids_count
+            profile_stats['missing_cis_refs_count'] = missing_cis_refs_count
+            profile_stats['missing_hipaa_refs_count'] = missing_hipaa_refs_count
+            profile_stats['missing_anssi_refs_count'] = missing_anssi_refs_count
             profile_stats['missing_ovals_count'] = len(profile_stats['missing_ovals'])
             profile_stats['missing_bash_fixes_count'] = len(profile_stats['missing_bash_fixes'])
             profile_stats['missing_ansible_fixes_count'] = len(profile_stats['missing_ansible_fixes'])
@@ -515,6 +575,9 @@ class XCCDFBenchmark(object):
                 del profile_stats['missing_puppet_fixes']
                 del profile_stats['missing_anaconda_fixes']
                 del profile_stats['missing_stig_ids']
+                del profile_stats['missing_cis_refs']
+                del profile_stats['missing_hipaa_refs']
+                del profile_stats['missing_anssi_refs']
             if not options.missing_cces:
                 del profile_stats['missing_cces']
             if not options.implemented_ovals:
